==> visualvm_1.1.1.orig.tar.gz: visualvm/threaddump/src/com/sun/tools/visualvm/threaddump/ThreadDumpDescriptor.java <==
/*
 * Copyright 2007-2008 Sun Microsystems, Inc.  All Rights Reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the LICENSE file that accompanied this code.
 * 
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 * 
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 * 
 * Please contact Sun Microsystems, Inc., 4150 Network Circle, Santa Clara,
 * CA 95054 USA or visit www.sun.com if you need additional information or
 * have any questions.
 */

package com.sun.tools.visualvm.threaddump;

import com.sun.tools.visualvm.core.snapshot.SnapshotDescriptor;
import com.sun.tools.visualvm.core.snapshot.SnapshotsSupport;
import java.awt.Image;
import org.openide.util.ImageUtilities;

/**
 * DataSourceDescriptor for ThreadDump.
 *
 * @author Jiri Sedlacek
 */
public class ThreadDumpDescriptor extends SnapshotDescriptor<ThreadDump> {
        
    private static final Image ICON = SnapshotsSupport.getInstance().createSnapshotIcon(
            ImageUtilities.loadImage("com/sun/tools/visualvm/threaddump/resources/threaddumpBase.png", true)); // NOI18N

    /**
     * Creates new instance of ThreadDumpDescriptor.
     * 
     * @param threadDump
     */
    public ThreadDumpDescriptor(ThreadDump threadDump) {
        super(threadDump, ICON);
    }
        
}

==> visualvm_1.2.2.orig.tar.gz: visualvm/threaddump/src/com/sun/tools/visualvm/threaddump/ThreadDumpDescriptor.java <==
/*
 * Copyright 2007-2008 Sun Microsystems, Inc.  All Rights Reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the LICENSE file that accompanied this code.
 * 
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 * 
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 * 
 * Please contact Sun Microsystems, Inc., 4150 Network Circle, Santa Clara,
 * CA 95054 USA or visit www.sun.com if you need additional information or
 * have any questions.
 */

package com.sun.tools.visualvm.threaddump;

import com.sun.tools.visualvm.core.snapshot.SnapshotDescriptor;
import com.sun.tools.visualvm.core.snapshot.SnapshotsSupport;
import java.awt.Image;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle;

/**
 * DataSourceDescriptor for ThreadDump.
 *
 * @author Jiri Sedlacek
 */
public class ThreadDumpDescriptor extends SnapshotDescriptor<ThreadDump> {
        
    private static final Image ICON = SnapshotsSupport.getInstance().createSnapshotIcon(
            ImageUtilities.loadImage("com/sun/tools/visualvm/threaddump/resources/threaddumpBase.png", true)); // NOI18N

    /**
     * Creates new instance of ThreadDumpDescriptor.
     * 
     * @param threadDump
     */
    public ThreadDumpDescriptor(ThreadDump threadDump) {
        super(threadDump, ICON);
    }

    public String getDescription() {
        return NbBundle.getMessage(ThreadDumpDescriptor.class, "DESCR_ThreadDump"); // NOI18N
    }
        
}
